@@ -6,11 +6,13 @@ package config
 import (
 	"errors"
 	"fmt"
+	"io/fs"
 	"os"
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config/data"
 	"github.com/derailed/k9s/internal/config/json"
+	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/rs/zerolog/log"
 	"gopkg.in/yaml.v2"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
@@ -52,14 +54,13 @@ func (c *Config) ContextAliasesPath() string {
 }
 
 // ContextPluginsPath returns a context specific plugins file spec.
-func (c *Config) ContextPluginsPath() string {
+func (c *Config) ContextPluginsPath() (string, error) {
 	ct, err := c.K9s.ActiveContext()
 	if err != nil {
-		log.Error().Err(err).Msgf("active context load failed")
-		return ""
+		return "", err
 	}
 
-	return AppContextPluginsFile(ct.GetClusterName(), c.K9s.activeContextName)
+	return AppContextPluginsFile(ct.GetClusterName(), c.K9s.activeContextName), nil
 }
 
 // Refine the configuration based on cli args.
@@ -87,6 +88,7 @@ func (c *Config) Refine(flags *genericclioptions.ConfigFlags, k9sFlags *Flags, c
 	switch {
 	case k9sFlags != nil && IsBoolSet(k9sFlags.AllNamespaces):
 		ns = client.NamespaceAll
+		c.ResetActiveView()
 	case isStringSet(flags.Namespace):
 		ns = *flags.Namespace
 	default:
@@ -180,6 +182,20 @@ func (c *Config) ActiveView() string {
 	return cmd
 }
 
+func (c *Config) ResetActiveView() {
+	if isStringSet(c.K9s.manualCommand) {
+		return
+	}
+	v := c.ActiveView()
+	if v == "" {
+		return
+	}
+	p := cmd.NewInterpreter(v)
+	if p.HasNS() {
+		c.SetActiveView(p.Cmd())
+	}
+}
+
 // SetActiveView sets current context active view.
 func (c *Config) SetActiveView(view string) {
 	if ct, err := c.K9s.ActiveContext(); err == nil {
@@ -209,9 +225,9 @@ func (c *Config) Merge(c1 *Config) {
 }
 
 // Load loads K9s configuration from file.
-func (c *Config) Load(path string) error {
-	if _, err := os.Stat(path); os.IsNotExist(err) {
-		if err := c.Save(); err != nil {
+func (c *Config) Load(path string, force bool) error {
+	if _, err := os.Stat(path); errors.Is(err, fs.ErrNotExist) {
+		if err := c.Save(force); err != nil {
 			return err
 		}
 	}
@@ -234,12 +250,12 @@ func (c *Config) Load(path string) error {
 }
 
 // Save configuration to disk.
-func (c *Config) Save() error {
+func (c *Config) Save(force bool) error {
 	c.Validate()
-	if err := c.K9s.Save(); err != nil {
+	if err := c.K9s.Save(force); err != nil {
 		return err
 	}
-	if _, err := os.Stat(AppConfigFile); os.IsNotExist(err) {
+	if _, err := os.Stat(AppConfigFile); errors.Is(err, fs.ErrNotExist) {
 		return c.SaveFile(AppConfigFile)
 	}
 
