@@ -79,6 +79,7 @@ func (o DrainOptions) toDrainHelper(k kubernetes.Interface, w io.Writer) drain.H
 		Timeout:             o.Timeout,
 		DeleteEmptyDirData:  o.DeleteEmptyDirData,
 		IgnoreAllDaemonSets: o.IgnoreAllDaemonSets,
+		DisableEviction:     o.DisableEviction,
 		Out:                 w,
 		ErrOut:              w,
 		Force:               o.Force,
@@ -248,7 +249,7 @@ func (n *Node) ensureCordoned(path string) (bool, error) {
 // FetchNode retrieves a node.
 func FetchNode(ctx context.Context, f Factory, path string) (*v1.Node, error) {
 	_, n := client.Namespaced(path)
-	auth, err := f.Client().CanI(client.ClusterScope, "v1/nodes", n, []string{"get"})
+	auth, err := f.Client().CanI(client.ClusterScope, "v1/nodes", n, client.GetAccess)
 	if err != nil {
 		return nil, err
 	}
@@ -272,7 +273,7 @@ func FetchNode(ctx context.Context, f Factory, path string) (*v1.Node, error) {
 
 // FetchNodes retrieves all nodes.
 func FetchNodes(ctx context.Context, f Factory, labelsSel string) (*v1.NodeList, error) {
-	auth, err := f.Client().CanI(client.ClusterScope, "v1/nodes", "", []string{client.ListVerb})
+	auth, err := f.Client().CanI(client.ClusterScope, "v1/nodes", "", client.ListAccess)
 	if err != nil {
 		return nil, err
 	}
