@@ -72,6 +72,11 @@ func (p *PortForwarder) Port() string {
 	return p.tunnel.PortMap()
 }
 
+// Address returns the port Address.
+func (p *PortForwarder) Address() string {
+	return p.tunnel.Address
+}
+
 // ContainerPort returns the container port.
 func (p *PortForwarder) ContainerPort() string {
 	return p.tunnel.ContainerPort
@@ -117,7 +122,7 @@ func (p *PortForwarder) Start(path string, tt port.PortTunnel) (*portforward.Por
 	p.path, p.tunnel, p.age = path, tt, time.Now()
 
 	ns, n := client.Namespaced(path)
-	auth, err := p.Client().CanI(ns, "v1/pods", n, []string{client.GetVerb})
+	auth, err := p.Client().CanI(ns, "v1/pods", n, client.GetAccess)
 	if err != nil {
 		return nil, err
 	}
