@@ -171,7 +171,7 @@ func (t *TableData) rxFilter(q string, inverse bool) (*RowEvents, error) {
 	if _, ok := t.header.IndexOf("NAMESPACE", true); ok && client.IsNamespaced(t.namespace) {
 		startIndex = 1
 	}
-	rr := NewRowEvents(50)
+	rr := NewRowEvents(t.RowCount() / 2)
 	ageIndex, _ := t.header.IndexOf("AGE", true)
 	t.rowEvents.Range(func(_ int, re RowEvent) bool {
 		ff := re.Row.Fields[startIndex:]
@@ -212,12 +212,11 @@ func (t *TableData) fuzzyFilter(q string) *RowEvents {
 }
 
 func (t *TableData) filterToast() *RowEvents {
+	rr := NewRowEvents(10)
 	idx, ok := t.header.IndexOf("VALID", true)
 	if !ok {
-		return nil
+		return rr
 	}
-
-	rr := NewRowEvents(10)
 	t.rowEvents.Range(func(_ int, re RowEvent) bool {
 		if re.Row.Fields[idx] != "" {
 			rr.Add(re)
