@@ -7,6 +7,7 @@ import (
 	"os"
 	"testing"
 
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/rs/zerolog"
 	"github.com/stretchr/testify/assert"
 )
@@ -18,23 +19,23 @@ func init() {
 func TestAugmentRow(t *testing.T) {
 	uu := map[string]struct {
 		file string
-		e    Fields
+		e    model1.Fields
 	}{
 		"cool": {
 			"testdata/b1.txt",
-			Fields{"pass", "3.3544", "29.8116", "100", "0"},
+			model1.Fields{"pass", "3.3544", "29.8116", "100", "0"},
 		},
 		"2XX": {
 			"testdata/b4.txt",
-			Fields{"pass", "3.3544", "29.8116", "160", "0"},
+			model1.Fields{"pass", "3.3544", "29.8116", "160", "0"},
 		},
 		"4XX/5XX": {
 			"testdata/b2.txt",
-			Fields{"pass", "3.3544", "29.8116", "100", "12"},
+			model1.Fields{"pass", "3.3544", "29.8116", "100", "12"},
 		},
 		"toast": {
 			"testdata/b3.txt",
-			Fields{"fail", "2.3688", "35.4606", "0", "0"},
+			model1.Fields{"fail", "2.3688", "35.4606", "0", "0"},
 		},
 	}
 
@@ -44,7 +45,7 @@ func TestAugmentRow(t *testing.T) {
 			data, err := os.ReadFile(u.file)
 
 			assert.Nil(t, err)
-			fields := make(Fields, 8)
+			fields := make(model1.Fields, 8)
 			b := Benchmark{}
 			b.augmentRow(fields, string(data))
 			assert.Equal(t, u.e, fields[2:7])
