@@ -8,6 +8,7 @@ import (
 	"strconv"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/tview"
 	appsv1 "k8s.io/api/apps/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
@@ -20,26 +21,24 @@ type DaemonSet struct {
 }
 
 // Header returns a header row.
-func (DaemonSet) Header(ns string) Header {
-	h := Header{
-		HeaderColumn{Name: "NAMESPACE"},
-		HeaderColumn{Name: "NAME"},
-		HeaderColumn{Name: "VS", VS: true},
-		HeaderColumn{Name: "DESIRED", Align: tview.AlignRight},
-		HeaderColumn{Name: "CURRENT", Align: tview.AlignRight},
-		HeaderColumn{Name: "READY", Align: tview.AlignRight},
-		HeaderColumn{Name: "UP-TO-DATE", Align: tview.AlignRight},
-		HeaderColumn{Name: "AVAILABLE", Align: tview.AlignRight},
-		HeaderColumn{Name: "LABELS", Wide: true},
-		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "AGE", Time: true},
+func (DaemonSet) Header(ns string) model1.Header {
+	return model1.Header{
+		model1.HeaderColumn{Name: "NAMESPACE"},
+		model1.HeaderColumn{Name: "NAME"},
+		model1.HeaderColumn{Name: "VS", VS: true},
+		model1.HeaderColumn{Name: "DESIRED", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "CURRENT", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "READY", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "UP-TO-DATE", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "AVAILABLE", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "LABELS", Wide: true},
+		model1.HeaderColumn{Name: "VALID", Wide: true},
+		model1.HeaderColumn{Name: "AGE", Time: true},
 	}
-
-	return h
 }
 
 // Render renders a K8s resource to screen.
-func (d DaemonSet) Render(o interface{}, ns string, r *Row) error {
+func (d DaemonSet) Render(o interface{}, ns string, r *model1.Row) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
 		return fmt.Errorf("expected DaemonSet, but got %T", o)
@@ -51,7 +50,7 @@ func (d DaemonSet) Render(o interface{}, ns string, r *Row) error {
 	}
 
 	r.ID = client.MetaFQN(ds.ObjectMeta)
-	r.Fields = Fields{
+	r.Fields = model1.Fields{
 		ds.Namespace,
 		ds.Name,
 		computeVulScore(ds.ObjectMeta, &ds.Spec.Template.Spec),
