@@ -22,7 +22,7 @@ import (
 
 const (
 	labelNodeRolePrefix = "node-role.kubernetes.io/"
-	nodeLabelRole       = "kubernetes.io/role"
+	labelNodeRoleSuffix = "kubernetes.io/role"
 )
 
 // Node renders a K8s Node to screen.
@@ -39,6 +39,7 @@ func (Node) Header(string) model1.Header {
 		model1.HeaderColumn{Name: "ARCH", Wide: true},
 		model1.HeaderColumn{Name: "TAINTS"},
 		model1.HeaderColumn{Name: "VERSION"},
+		model1.HeaderColumn{Name: "OS-IMAGE", Wide: true},
 		model1.HeaderColumn{Name: "KERNEL", Wide: true},
 		model1.HeaderColumn{Name: "INTERNAL-IP", Wide: true},
 		model1.HeaderColumn{Name: "EXTERNAL-IP", Wide: true},
@@ -95,6 +96,7 @@ func (n Node) Render(o interface{}, ns string, r *model1.Row) error {
 		no.Status.NodeInfo.Architecture,
 		strconv.Itoa(len(no.Spec.Taints)),
 		no.Status.NodeInfo.KubeletVersion,
+		no.Status.NodeInfo.OSImage,
 		no.Status.NodeInfo.KernelVersion,
 		iIP,
 		eIP,
@@ -181,7 +183,7 @@ func nodeRoles(node *v1.Node, res []string) {
 				res[index] = role
 				index++
 			}
-		case k == nodeLabelRole && v != "":
+		case strings.HasSuffix(k, labelNodeRoleSuffix) && v != "":
 			res[index] = v
 			index++
 		}
