@@ -7,6 +7,7 @@ import (
 	"errors"
 	"testing"
 
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/stretchr/testify/assert"
 )
@@ -46,7 +47,7 @@ func TestPolicyResMerge(t *testing.T) {
 func TestPolicyRender(t *testing.T) {
 	var p render.Policy
 
-	var r render.Row
+	var r model1.Row
 	o := render.PolicyRes{
 		Namespace:      "blee",
 		Binding:        "fred",
@@ -59,7 +60,7 @@ func TestPolicyRender(t *testing.T) {
 
 	assert.Nil(t, p.Render(o, "fred", &r))
 	assert.Equal(t, "blee/res", r.ID)
-	assert.Equal(t, render.Fields{
+	assert.Equal(t, model1.Fields{
 		"blee",
 		"res",
 		"grp",
