@@ -6,6 +6,7 @@ package render
 import (
 	"fmt"
 
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/tcell/v2"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -17,31 +18,31 @@ type Subject struct {
 }
 
 // ColorerFunc colors a resource row.
-func (Subject) ColorerFunc() ColorerFunc {
-	return func(ns string, _ Header, re RowEvent) tcell.Color {
+func (Subject) ColorerFunc() model1.ColorerFunc {
+	return func(ns string, _ model1.Header, re *model1.RowEvent) tcell.Color {
 		return tcell.ColorMediumSpringGreen
 	}
 }
 
 // Header returns a header row.
-func (Subject) Header(ns string) Header {
-	return Header{
-		HeaderColumn{Name: "NAME"},
-		HeaderColumn{Name: "KIND"},
-		HeaderColumn{Name: "FIRST LOCATION"},
-		HeaderColumn{Name: "VALID", Wide: true},
+func (Subject) Header(ns string) model1.Header {
+	return model1.Header{
+		model1.HeaderColumn{Name: "NAME"},
+		model1.HeaderColumn{Name: "KIND"},
+		model1.HeaderColumn{Name: "FIRST LOCATION"},
+		model1.HeaderColumn{Name: "VALID", Wide: true},
 	}
 }
 
 // Render renders a K8s resource to screen.
-func (s Subject) Render(o interface{}, ns string, r *Row) error {
+func (s Subject) Render(o interface{}, ns string, r *model1.Row) error {
 	res, ok := o.(SubjectRes)
 	if !ok {
 		return fmt.Errorf("expected SubjectRes, but got %T", s)
 	}
 
 	r.ID = res.Name
-	r.Fields = Fields{
+	r.Fields = model1.Fields{
 		res.Name,
 		res.Kind,
 		res.FirstLocation,
