@@ -35,7 +35,9 @@ type CronJob struct {
 
 // NewCronJob returns a new viewer.
 func NewCronJob(gvr client.GVR) ResourceViewer {
-	c := CronJob{ResourceViewer: NewVulnerabilityExtender(NewBrowser(gvr))}
+	c := CronJob{ResourceViewer: NewVulnerabilityExtender(
+		NewOwnerExtender(NewBrowser(gvr)),
+	)}
 	c.AddBindKeysFn(c.bindKeys)
 	c.GetTable().SetEnterFn(c.showJobs)
 
