@@ -8,6 +8,8 @@ import (
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
+	v1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 // LogsExtender adds log actions to a given viewer.
@@ -91,3 +93,27 @@ func (l *LogsExtender) buildLogOpts(path, co string, prevLogs bool) *dao.LogOpti
 
 	return &opts
 }
+
+func podLogOptions(app *App, fqn string, prev bool, m metav1.ObjectMeta, spec v1.PodSpec) *dao.LogOptions {
+	var (
+		cc   = fetchContainers(m, spec, true)
+		cfg  = app.Config.K9s.Logger
+		opts = dao.LogOptions{
+			Path:            fqn,
+			Lines:           int64(cfg.TailCount),
+			SinceSeconds:    cfg.SinceSeconds,
+			SingleContainer: len(cc) == 1,
+			ShowTimestamp:   cfg.ShowTime,
+			Previous:        prev,
+		}
+	)
+	if c, ok := dao.GetDefaultContainer(m, spec); ok {
+		opts.Container, opts.DefaultContainer = c, c
+	} else if len(cc) == 1 {
+		opts.Container = cc[0]
+	} else {
+		opts.AllContainers = true
+	}
+
+	return &opts
+}
